==> yangtze-request-0.5.1.tgz: package/README.md <==
# yangtze-request

长江大数据前端通用请求方法，基于 umi-request 封装

## 基础功能

1. 通用接口请求
2. 统一错误提示方案封装
3. 默认超时时间：3s

## 使用方法

1.  引入  
    `npm i yangtze-request --save` 或 `yarn add yangtze-request`
2.  使用

    - 在 initRequest 方法调用前注册错误处理函数，否则仅 console.log 提示错误信息
    - 注册错误处理函数时 common 属性提供的方法即通用错误处理函数，可抛出除特殊处理方案外的全部错误信息

      ```js
      import { registerErrorHandler } from 'yangtze-request';
      registerErrorHandler({
        common: ({ errorCode, errorMessage, data }) => {
          message.error(`${errorCode}: ${errorMessage}`);
        },
        401: ({ errorCode, errorMessage, data }) => {
          history.push('/login');
        },
        403: () => {
          history.push('/403');
        },
      });
      ```

    - 通用实例 initRequest，传入参数

      `initRequest(url, options, entendOptions)`

      ```js
      // get 方法
      import { initRequest } from 'yangtze-request';
      const url = '/api/user/info';
      const result = await initRequest(url, {
        method: 'get',
        params: { id: 1 },
      });
      ```

      ```js
      // post 方法
      import { initRequest } from 'yangtze-request';
      const url = '/api/user/add';
      const result = await initRequest(url, {
        method: 'post',
        data: { name: 'oo' },
      });
      ```

      ```js
      // 通用文件上传
      import { initRequest } from 'yangtze-request';
      const url = '/api/upload';
      const formData = new FormData();
      formData.append('file', file);
      const result = await initRequest(url, {
        method: 'post',
        requestType: 'form',
        data: formData,
      });
      ```

      ```js
      // 二进制流
      import { initRequest } from 'yangtze-request';
      const url = '/api/download';
      const result = await initRequest(url, {
        method: 'get',
        params: { bucketName: '', filename: '' },
        responseType: 'blob',
      });
      ```

    - 如有扩展请求实例通用配置的需要，使用 createInstance 方法创建实例，传入配置参数

      ```js
      import { createInstance } from "yangtze-request";
      const request = createInstance({
        responseType: "blob",
        timeout: 5000,
      });
      export request;
      ```

    - 更多功能拓展请参考 [umi-request](https://github.com/umijs/umi-request)

## 版本信息

| 版本号 | 更新日期   | 更新内容                           |
| ------ | ---------- | ---------------------------------- |
| v0.1.0 | 2022-08-04 | 封装统一错误处理逻辑的统一请求方案 |
| v0.2.0 | 2022-08-30 | 增加文件上传下载                   |
| v0.3.0 | 2022-08-30 | 增加文件流默认处理                 |

==> yangtze-request-1.0.0.tgz: package/README.md <==
# yangtze-request

长江大数据前端通用请求方法，基于 umi-request 封装

## 基础功能

1. 通用接口请求
2. 统一错误提示方案封装
3. 默认超时时间：3s

## 使用方法

1.  引入  
    `npm i yangtze-request --save` 或 `yarn add yangtze-request`
2.  使用

    - 在 initRequest 方法调用前注册错误处理函数，否则仅 console.log 提示错误信息
    - 注册错误处理函数时 common 属性提供的方法即通用错误处理函数，可抛出除特殊处理方案外的全部错误信息

      ```js
      import { registerErrorHandler } from 'yangtze-request';
      registerErrorHandler({
        common: ({ statusCode, statusMessage, data }) => {
          message.error(`${statusCode}: ${statusMessage}`);
        },
        401: ({ statusCode, statusMessage, data }) => {
          history.push('/login');
        },
        403: () => {
          history.push('/403');
        },
      });
      ```

    - 通用实例 initRequest，传入参数

      `initRequest(url, options, entendOptions)`

      ```js
      // get 方法
      import { initRequest } from 'yangtze-request';
      const url = '/api/user/info';
      const result = await initRequest(url, {
        method: 'get',
        params: { id: 1 },
      });
      ```

      ```js
      // post 方法
      import { initRequest } from 'yangtze-request';
      const url = '/api/user/add';
      const result = await initRequest(url, {
        method: 'post',
        data: { name: 'oo' },
      });
      ```

      ```js
      // 通用文件上传
      import { initRequest } from 'yangtze-request';
      const url = '/api/upload';
      const formData = new FormData();
      formData.append('file', file);
      const result = await initRequest(url, {
        method: 'post',
        requestType: 'form',
        data: formData,
      });
      ```

      ```js
      // 二进制流
      import { initRequest } from 'yangtze-request';
      const url = '/api/download';
      const result = await initRequest(url, {
        method: 'get',
        params: { bucketName: '', filename: '' },
        responseType: 'blob',
      });
      ```

    - 如有扩展请求实例通用配置的需要，使用 createInstance 方法创建实例，传入配置参数

      ```js
      import { createInstance } from "yangtze-request";
      const request = createInstance({
        responseType: "blob",
        timeout: 5000,
      });
      export request;
      ```

    - 更多功能拓展请参考 [umi-request](https://github.com/umijs/umi-request)

## 版本信息

| 版本号 | 更新日期   | 更新内容                           |
| ------ | ---------- | ---------------------------------- |
| v0.1.0 | 2022-08-04 | 封装统一错误处理逻辑的统一请求方案 |
| v0.2.0 | 2022-08-30 | 增加文件上传下载                   |
| v0.3.0 | 2022-08-30 | 增加文件流默认处理                 |
